@@ -15,5 +15,7 @@ void tsl_create_upper_paths_hook(PlannerInfo *, UpperRelationKind, RelOptInfo *,
 								 TsRelType, Hypertable *, void *);
 void tsl_set_rel_pathlist_query(PlannerInfo *, RelOptInfo *, Index, RangeTblEntry *, Hypertable *);
 void tsl_set_rel_pathlist_dml(PlannerInfo *, RelOptInfo *, Index, RangeTblEntry *, Hypertable *);
+void tsl_sort_transform_replace_pathkeys(void *path, List *transformed_pathkeys,
+										 List *original_pathkeys);
 void tsl_preprocess_query(Query *parse, int *cursor_opts);
 void tsl_postprocess_plan(PlannedStmt *stmt);
